def mail(name):
    print(f'Дорогой {name}!')
    print(f'Нет слов таких, чтобы описать, насколько ты обоссаный даун. И чисел таких не было придумано, чтобы обозначить количество негров, которые ебали твою мать, {name}.', end=' ')
    print('Желаю тебе поскорее сдохнуть, чтобы твоё тело выебали все твои отчимы. Я надеюсь, мы все будет присутствовать на твоих похоронах, чтобы коллективно настрать тебе в гроб.')
    print(f'Желаю тебе, {name}, всего самого наилучшего, особенно удачи в многочисленных гей-оргиях, в которых ты принимаешь участие. Удачи тебе и твоему поравнному очку.')
    print(f'Надеюсь на скорую встречу с тобой, {name}, и твоей мамой.')
